![](https://www.phonexia.com/wp-content/uploads/phonexia-logo-transparent-500px.png)

# Phonexia language identification client

This module contains client for communication with [language identification microservice](https://hub.docker.com/repository/docker/phonexia/language-identification/general) developed by [Phonexia](https://phonexia.com).

To use this client you will first need a running instance of any *Phonexia language identification microservice*. If you don't yet have any running instance, don't hesitate to [contact our sales department](mailto:info@phonexia.com).

You can learn more about the language identification technology [here](https://docs.cloud.phonexia.com/docs/products/speech-platform-4/microservices/installation/language-identification/).

On [this page](docs.cloud.phonexia.com/docs/products/speech-platform-4/grpc/api/phonexia/grpc/technologies/language_identification/v1/language_identification.proto), you will find a *gRPC API* reference for *language identification microservice*.